@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 from __future__ import print_function
 import stretch_body.lift as lift
 import argparse
@@ -9,7 +9,7 @@ parser=argparse.ArgumentParser(description='Calibrate the lift position by movin
 args=parser.parse_args()
 
 l=lift.Lift()
-if not l.startup():
+if not l.startup(threaded=False):
     exit()
 l.home()
 l.stop()
